@@ -24,10 +24,6 @@ class FerhassioSaver:
         self.time_spent = 0
         self.workers_count = 0
 
-        assert self.async_db.context == 'async'
-        assert self.async_aql.context == 'async'
-        assert self.async_coll.context == 'async'
-
     def create_unique_field(self, field: str):
         """
         Create unique index in document
@@ -96,7 +92,7 @@ class FerhassioSaver:
         chunk_generator = [json_list[i:i + chunk_size] for i in range(0, len(json_list), chunk_size)]
 
         for chunk in chunk_generator:
-            self.async_coll.import_bulk(chunk, on_duplicate='replace')
+            self.async_coll.import_bulk(chunk, on_duplicate=on_duplicate)
             self.workers_count += 1
 
         transaction_end_time = time.time()
@@ -109,7 +105,7 @@ class FerhassioSaver:
         :param overwrite_mode: update(default), replace
         :return: None
         """
-        self.async_coll.insert(doc, overwrite_mode='update')
+        self.async_coll.insert(doc, overwrite_mode=overwrite_mode)
 
     def is_valid(self, doc):
         """
